function [saisir] = appendrow(saisir1,saisir2)
%appendrow 		- merges two SAISIR matrices according to rows 
% usage: [X3]= appendrow(X1,X2) 
%
%Input arguments:
%================
%X1, X2 : SAISIR Matrix dimensionned n1 x p and n2 x p
%
%Ouput argument:
%==============
%X3     : SAISIR Matrix  dimensionned (n1+n2) x p
%
%The identifiers or columns are recopied in X3.v
%The identifiers of rows are the concatenation of X1.i and X2.i
%
%Example:
%total=appendrow(spectra1, spectra2);
%
%see also: appendcol, appendrow1, appendcol1

if(isempty(saisir1))
    saisir=saisir2;
    return;
end
if(isempty(saisir2))
    saisir=saisir1;
    return;
end


if(size(saisir1.d,2)~=size(saisir2.d,2))
   help appendrow;
   error('number of columns are not equal');
end   

[n1,p1]=size(saisir1.i);
[n2,p2]=size(saisir2.i);

saisir.d=[saisir1.d;saisir2.d];
if(p1~=p2)
   code='                                     ';
   aux=char(ones(n1,1)*code);
	saisir1.i=[saisir1.i aux];
   aux=char(ones(n2,1)*code);
   saisir2.i=[saisir2.i aux];
   saisir.i=[saisir1.i(:,1:20);saisir2.i(:,1:20)];
else
   saisir.i=[saisir1.i;saisir2.i];
   saisir.v=saisir1.v;
end

