function res = apply_quaddis(quaddis_type,x,known_group);
%apply_quaddis        - Quadratic discriminant analysis 
%function result = apply_quaddis(quaddis_type,x,(known_group));
% Application of quadratic discriminant analysis (test) 
% ====================================================
% Input arguments: 
% ================
% quaddis_type : output of function "quaddis" (structure)
% x            : predictive data matrix (n x p) 
% known_group  : true groups of observations in x (n x 1) (optional)
%
% Ouput arguments: 
% ================
% result with fields:
%predgroup      :  predicted groups (n x 1) 
%density        : pseudo-density (n x gmax)
%proba          : probability of belonging to a given group (n x gmax)
%   if "known_group" defined
%nscorrect100   : percentage of correct classification (number)
%sconfus        : confusion matrix (gmax x gmax)

[nind,nvar]=size(x.d);
xdet=quaddis_type.model.det;
Mut=quaddis_type.model.Mut;
xinv=quaddis_type.model.inv;
Tcla=length(xdet);

for i=1:nind
    x1=x.d(i,:);
    for t=1:Tcla
        Densite(i,t)=(1/(((2*pi).^((nvar)/2))*(xdet(t).^0.5)))*exp(-0.5*(x1-Mut(t,:))*xinv(:,:,t)*(x1-Mut(t,:))');
    end;
    Zht(i,:)=Densite(i,:)./sum(Densite(i,:));%% probability of belonging to a given class
end;
%Zht

[Y,I]=max(Zht');
Zhtclass=I';

res.predgroup.d=Zhtclass;
res.predgroup.i=x.i;
res.predgroup.v='predicted groups';

res.density=matrix2saisir(Densite);;
res.density.i=x.i;
res.proba=matrix2saisir(Zht);
res.proba.i=x.i;

if(nargin>2); %% groups are known (situation of validation)
    confus=zeros(Tcla,Tcla);
    for i=1:nind
        confus(known_group.d(i),Zhtclass(i))=confus(known_group.d(i),Zhtclass(i))+1;
    end
    confus=matrix2saisir(confus);
    confus.i=addcode(confus.i,'observed group # ');
    confus.v=addcode(confus.v,'predicted group # ');
    ncorrect=sum(diag(confus.d));
    res.nscorrect100=ncorrect/nind*100;
    res.sconfus=confus;

end


    