function[res]=apply_stepwise_regression(type,x,y)
%apply_stepwise_regression			- applies stepwise_regression on "unknown" data
%function[res]=apply_stepwise_regression(stepwise_type,X,(y))
%Input arguments:
%================
%stepwise_type: array of cells obtained as output of stepwise_regression 
%X            : SAISIR matrix of predictive variables (n x p) 
%y            : SAISIR vector of observed variable (n x 1) 
%
%Output argument
%===============
%res with fields
%predy : predicted y for all the tested models
%rmsev : Root mean square error of validation (if input argument "y"
%defined)
%r2    : determination coefficients between oobserved and predicted y
%
%build as many models as available in "stepwise_type"


[n,p]=size(x.d);
if(nargin>2)
[n1,p1]=size(y.d);
end;
nmodel=size(type,2);
for model=1:nmodel
   aux=type{model};
   if(isempty(aux));break;end;
   intercept=aux.intercept;
   rang=aux.res.d(:,7)';
   coeff=aux.res.d(:,1);
   mat=x.d(:,rang);
   res.predy.d(:,model)=mat*coeff+intercept;
   res.predy.i=x.i;
   aux=[num2str(model) '               '];
   res.predy.v(model,:)=aux(1:10);
	if(nargin>2)   
      delta=y.d(:,1)-res.predy.d(:,model);
      res.rmsev.d(model)=sqrt(sum(delta.*delta)/n);   
    if(n1>1)% impossible to calculate corr if size(y.d,1)<2
        s=std(y.d);
        if(s>0)% impossible to assess corr if y always the same
            co=corrcoef(res.predy.d(:,model),y.d);
	        res.r2.d(model)=co(1,2)*co(1,2);
        else
            disp('all the y identical, impossible to assess correlation coefficient');
        end
    end
end
end
if(nargin>2)
	   res.rmsev.v=res.predy.v;
	res.r2.v=res.rmsev.v;
	res.r2.i='Determination coefficient';
    res.rmsev.i='RMSEV';
end
