function res1=basic_pls2(x,y,maxdim)
%basic_pls2            - PLS2 on several variables, several dimensions
%function result=basic_pls2(X,y,maxdim)
%
%Input arguments:
%===============
%X: SAISIR matrix of predictive variables ( n x p)
%y: SAISIR vector of observed y (n x m)
%maxdim (integer): maximum number of PLS dimensions
%
%Ouput arguments:
%===============
%result with fields
%T: PLS scores (n x maxdim)
%loadings: PLS loadings (p x maxdim)
%meanx: average of X (1 x p)
%res: array of cells (maxdim elements)
%A structure in res{i} with i = 1 ... maxdim contains the results of the
%prediction of the variable i.
%
%result.res{i} has the fields:
%nom: (string) , name of the considered variable i
%BETA (p  x maxdim): regression coefficients up to maxdim dimensions
%BETA0 (1 x maxdim): intercepts of the models
%PREDY (n x maxdim): predicted y for 1 to maxdim dimensions
%RMSEC (1 x maxdim): root mean square errors of calibration
%r2 (1 x maxdim): r2 for 1 to maxdim dimensions

X=x.d;
Y=y.d;
[n p2]=size(X);
[n p1]=size(Y);
ybar=mean(Y);
xbar=mean(X);
X=X-ones(n,1)*xbar;
Xkept=X;
Y=Y-ones(n,1)*ybar;    
Ykept=Y;
R=eye(size(X,2));
I=R;
BET=zeros(p2,p1,maxdim);
previous=BET(:,:,1);
for i=1:maxdim
    xdisp(i,' among ',maxdim);
    XY=X'*Y;      
    [u,s,v]=svd(XY,0);    
    w=u(:,1);
    t=X*w;
   	T.d(:,i)=t;	   
    e=t'*t;
    c=Y'*t/e;
    u=Y*c/(c'*c);
    p=X'*t/e;
   % disp([i u'*t]); 
    temp=I-w*p';%% Keeping linear transformation on X: this step
    beta=R*w*c';%OK2
    BET(:,:,i)=beta+previous;
    X=X-t*p';
    Y=Y-t*c';
    proj(:,i)=R*w;
    R=R*temp;% Keeping linear transformation on X: all the steps
    previous=BET(:,:,i);
end
clear temp;

for var=1:p1
    temp.d=reshape(BET(:,var,:),p2,maxdim);
    temp.i=x.v;
    temp.v=num2str((1:maxdim)');
    res{var}.nom=y.v(var,:);
    res{var}.BETA=temp;
    temp1.d=ybar(var)*ones(1,maxdim)-xbar*temp.d;
    temp1.i='Constant';
    temp1.v=temp.v;
    res{var}.BETA0=temp1;
    temp3.d=x.d*temp.d + ones(n,1)*temp1.d;
    temp3.i=y.i;
    temp3.v=temp.v;
    res{var}.PREDY=temp3;
    delta=y.d(:,var)*ones(1,maxdim)-temp3.d;
    temp4.d=sqrt(sum(delta.*delta)/n);
    temp4.i='Root mean square error of calibration';
    temp4.v=temp.v;
    res{var}.RMSEC=temp4;
    this_y=selectcol(y,var);
    temp5=cormap(this_y,res{var}.PREDY);
    temp5.d=temp5.d.*temp5.d;%% here error in previous version corrected 16/6/2005 !!!!!
    res{var}.r2=temp5;
end
T.i=x.i;
T.v=temp.v;
res1.res=res;
res1.T=T;
res1.loadings.d=proj;
res1.loadings.i=x.v;
res1.loadings.v=num2str((1:maxdim)');
res1.meanx=saisir_mean(x);