function build_documentation(directory_name,filename,thematic_list)
%function build_documentation(directory_name,filename,(thematic_list))
%
%Input arguments:
%================
%directory_name : name of the directory (working with 
%the Matlab command "what <directory>)
%file_name: name of the resulting html file 
%Extension ".htm" is added to this name
%thematic_list: output of function "thematic_classification"
%
%The function builds the HTML documentation of SAISIR by concatenation of the
%"Helps". If "thematic_list" is defined, gives also a thematic list of functions
%The resulting HTML file is in "filename" 
%
%Typical example
%===============
%aux=what('saisir');%% functions in the directory "saisir";
%function_name=char(aux.m);% list of function in SAISIR
%build_documentation('saisir','SAISIR documentation');%% builds the HTLM fields
%
%%For having also a thematic index in the HTML document, one must use the function 
%"thematic_classification".
%%For example
%mylist=thematic_classification(function_name);
%build_documentation('saisir','SAISIR_documentation',mylist);%% builds the HTLM fields
%Then the resulting SAISIR_documentation.htm file can be examined with WEB
%explorer such as Window explorer or firefox. Window explorer is better here. 
%
%See also: "thematic_classification"

aux=what(directory_name);
function_name=char(cat(1,aux.m));
[n,p]=size(function_name);
filename=lower(filename);
if(isempty(findstr('.htm',filename)))
   filename=[filename '.htm'];
end

fid=fopen(filename,'w');
%HTML HEADER =============================
xdisp('Building header');
html_header(fid);
%building the thematic list ===============
if(nargin>2)
    xdisp('Building thematic list');
    documentation_thematic_list(fid,directory_name,function_name,thematic_list);
end

%Building the alphabetic dictionnary =====
xdisp('Building alphabetic list');
documentation_dico(fid,function_name);
%gathering the helps of functions ========
xdisp('Building function helps');
html_notice(fid,function_name);
%%HTML Postface ==========================
html_postface(fid);
%% closing
fclose(fid);


%% local function : printing in the documentation file
function w(fid,text);
text=char(text);
[n,p]=size(text);
for i = 1 :n
fprintf(fid,'%s\n',text(i,:));;
end
