function[pcatype]=covariance_pca(covariance_type,ncomponent)
%covariance_pca         - principal component analysis when knowing the covariance (of variables) 
%function[pcatype]=covariance_pca(covariance_type,(nscore))
%
%Input arguments:
%---------------
%covariance_type: output argument of function "cumulate_covariance"
%nscore : (integer, optional) number of scores to be calculated (default :
%all)
%
%Output argument:
%----------------
%pcatype with fields:
%eigenvec: eigenvector
%eigenval:eigenvalues
%average:average value of the active observations
%
%Performs PCA on the covariance matrix as calculated by"cumulate_covariance"
% This function is useful fo to carrying on PCA with huge data set (see
% "cumulate_covariance" for an example of use)
%
%%typical example:
%A complete script must therefore be something like
%cov=cumulate_covariance(spectra_1);%% starting
%cov=cumulate_covariance(spectra_2,cov);%% cumulating values of matrix 1
%cov=cumulate_covariance(spectra_3,cov);%% cumulating values of matrix 2
%...
%cov=cumulate_covariance(spectra_k,cov);%% cumulating values of matrix k
%covariance_type=cumulate_covariance([],cov);%% finishing
%[pcatype]=covariance_pca(covariance_type,(ncomponent))
%score1=applypca(pcatype,spectra_1);%% projecting data from spectra_1 
%
%This function is mainly used to compute PCA on huge data set, which cannot
%be loaded completely in the free memory, and thust must be split in smaller subset of observations. 
%
%related function; "cumulate_covariance" (covariance of huge data set)
%
%

n=covariance_type.n;
p=size(covariance_type.d,2);
average=covariance_type.average;
%centred=covariance_type.d;
% Warning functin eig does not sort the eigenvalues and eigenvectors!!
%size(centred*centred')
[v,d]=eig(covariance_type.d);% diagonalisation matrix X'X centred
[eigenval.d, index]=sort(-abs(diag(d)'));% eigenvalues in increasing order!
r=p;%rank 
eigenval.d=-eigenval.d(1:r);
eigenval.i='eigenvalues';
% using dual properties
eigenvec.d=v;
% reordering eigenvector according to eigenvalues
eigenvec.d=eigenvec.d(:,index);
eigenvec.d=eigenvec.d(:,1:r);
% assessing the true scores
aux=sqrt(n);
%size(centred)
%size(eigenvec.d)
% identifiers
eigenvec.i=covariance_type.v;
% building identifier A1, A2, ... , Ap
for i=1:p
   chaine=['A' num2str(i) '        '];
   eigenvec.v(i,:)=chaine(1:6);
end
eigenval.v=eigenvec.v;
average.v=covariance_type.v;
average.i='average';
if(nargin>1);
    if(ncomponent<p)
        eigenvec=selectcol(eigenvec,1:ncomponent);
        eigenval=selectcol(eigenval,1:ncomponent);
    end
end

pcatype.eigenvec=eigenvec;
pcatype.eigenval=eigenval;

pcatype.average=average;
pcatype.nobservation=n;
