function[res]=crossval_multiple_regression(x,y,selected)
%crossval_multiple_regression			- validation of multiple regression. 
%function[res]=crossval_multiple_regression(X,y,selected)
%
%Input arguments:
%================
%X:         SAISIR matrix of predictive data (n x p)
%y:         SAISIR vector of the variable to be predicted ( n x 1) 
%selected:  MATLAB vector ( n x 1) giving the samples placed in the
%           verification set: 1= in verification; 0 = in calibration set 
%
%Output arguments:
%================
%res with fields:
%   calibration with fields
%       ypred: predicted y (n x1)
%       beta0: intercept of the regresssion
%       beta: regression coefficients (p x 1)
%       r2: r2 between observed and predicted values in calibration[1x1 struct]
%        RMSEC: Root mean square error of calibration
%   validation with fields
%       ypred predicted values in validation
%       r2: determination coefficient between obs and predicted values in
%       validation
%       RMSEV: Root mean square error of validation
%
%Divides the data into a calibration and a validation set.
%Multiple linear regression is established on the calibration set
%and validated on the validation set.
%The division calibration/validation is determined by the vector "selected"


nind=size(x.d,1);
[xval, xcal]=splitrow(x,selected==1);
[yval, ycal]=splitrow(y,selected==1);
model=multiple_regression(xcal,ycal);
[res1]=apply_multiple_regression(xval,model,yval);
res.calibration=model;
res.validation=res1;
