function [vect, index]=find_peaks(saisir,row,threshold,gap,min_max)
%find_peaks   - finds and displays peaks greater than a threshold value 
%function [vect, index]=find_peaks(X,nrow,threshold,windowsize,min_max)
%
%Input arguments
%==============
%X:SAISIR data matrix of "spectra-like" data
%nrow:(integer): index of the row to be studied
%threshold: peaks of absolute value lower than the threshold are not
%detected
%windowsize (integer, preferably odd number): size of the moving window 
%in which the peaks are to be found
%min_max: either 0 : only maximum detected, or 1: maximum and minimum detected 
%
%Output argument
%==============
%vect: matlab vector of the positions (name of variable converted into
%numbers) 
%index: matlab vector of the index of the variables corresponding to peaks 
%
%Inside a moving window of size "windowsize" (data points) 
%detects the maximum (or maximum and minimum values). The identified
%positions are considered as "peaks" and shown on the display.
%The corresponding variables identifiers (normally wavelengths, or
%retention time values) are converted into numbers and given in the output
%argument "vect".
%
%The system of threshold and moving window avoid that a large series of
%peaks will be identified if the studied curve is not perfectly smooth. 
%The "windowsize" indicates the minimum gap (in data points) between two
%consecutive peaks. The threshold makes it possible to detect peaks greater than a certain value.  

if(mod(gap,2)==0);gap=gap+1;end; %% not recommanded

vect=[];
index=[];
[n,p]=size(saisir.d);
peak.d=zeros(n,8);
if(nargin<4)
    min_max=0;
end
nel=0;
for i=row
   %disp(i);
   curve(saisir,i);
   x=saisir.d(i,:);
   aux=(gap+1)/2;
   aux1=aux-1;
   for j=aux:(p-aux);
       if(x(j)>threshold)
         [a,b]=sort(-x(j-aux1:j+aux1));
         if (b(1)==aux)
            posx=str2num(saisir.v(j,:));
            nel=nel+1;
            vect(nel)=posx;
            index(nel)=j;
            line([posx posx],[0 x(j)]);
         	text(posx,x(j),saisir.v(j,:),'FontSize',12);   
         end   
      end;   
    end   
 end
vect1=vect;
index1=index;
if(min_max>0)
clear vect;
vect=[];
clear index; 
index=[];
nel=0;
for i=row
   %disp(i);
   %courbe(saisir,i);
   x=saisir.d(i,:);
   aux=(gap+1)/2;
   aux1=aux-1;
   for j=aux:p-aux;
      if(abs(x(j))>threshold)
      [a,b]=sort(-x(j-aux1:j+aux1));
      %   [b(end) aux]
         if (b(end)==aux)
            posx=str2num(saisir.v(j,:));
            nel=nel+1;
            vect(nel)=posx;
            index(nel)=j;
            line([posx posx],[0 x(j)]);
         	text(posx,x(j),saisir.v(j,:),'FontSize',12);   
         end   
      end;   
    end   
end
vect=[vect1 vect];
index=[index1 index];
end
