function[discrtype]=maha1(saisir,group,maxvar,test,testgroup)
%maha1 			- forward linear discriminant analysis DIRECTLY ON DATA with validation samples
% function[discrtype1]=maha1(calibration_data,calibration_group,maxvar,test_data,test_group)
%
%Input arguments
%==============
%calibration_data: SAISIR matrix (n1 x p)
%calibration_group:SAISIR vector of group numbers (n1 x 1)
%maxvar:(integer) maximum number of variables introduced in the model
%test_data:SAISIR matrix (n2 x p)
%test_group: SAISIR vector of group numbers (n2 x 1);
%
%Output argument:
%===============
%discrtype1 with fields:
%step with fields
%  index: vector giving the rank of the variable introduced at each step
%  (maxvar values)
%  correct: vector giving the number of correct classifications in the
%  calibration set (max var values)
%  name: identifiers of the variables introduced int the models (matrix of
%  char with maxvar rows)
%  ntestcorrect: vector giving the number of correct classifications in the
%  validation set (max var values)
%classed: SAISIR vector of the predicted group numbers of the calibration
%  set (n1 x 1). Only the result of the final step is given
%testclassed:SAISIR vector of the predicted group numbers of the test set (n2 x 1)
%Only the result of the final step is given
%
% The function assesses a simple linear discriminant analysis introducing
% up to maxvar variables
% at each step, the more discriminating variable (according to the percentage of correct
% classification of the calibration set) is introduced. Only forward
% Uses the Matlab function "classify"
%
%%Typical example
%
%mydis=maha1(wheat1,g1,5,wheat2,g2)
%disp(mydis.step.ntestcorrect);%Looking at the number of correct
%%classifications in the test set

[nrow ncol]=size(saisir.d);
selected=zeros(1,ncol);
bestchoice=[];
for introduced=1:maxvar
   bestcorrect=0;
   for col=1:ncol
      if(selected(1,col)==0)
         currentchoice=[bestchoice;col];
         classed=classify(saisir.d(:,currentchoice),saisir.d(:,currentchoice),group.d);
         ncorrect=sum(classed==group.d);      
      	if(ncorrect>bestcorrect)
         	bestcorrect=ncorrect;
         	candidate=col;
      	end;   
   	end;      
   end;
   step.index(introduced)=candidate;
   step.correct(introduced)=bestcorrect;
   step.name(introduced,:)=saisir.v(candidate,:);
   selected(1,candidate)=1;
	bestchoice=[bestchoice;candidate];   
	testclassed=classify(test.d(:,bestchoice),saisir.d(:,bestchoice),group.d);   
	step.ntestcorrect(introduced)=sum(testclassed==testgroup.d);   
end;
discrtype.step=step;
discrtype.classed.d=classed;
discrtype.classed.i=saisir.i;
discrtype.classed.v='predicted group (calibration)'
discrtype.testclassed.d=testclassed;
discrtype.testclassed.i=testgroup.i;
discrtype.testclassed.v='predicted group (validation)'


