function[discrtype]=maha4(saisir,group,maxvar)
%maha4 	- simple discriminant analysis forward  
%function[discrtype]=maha4(X,group,maxvar)
%
%Input arguments:
%----------------
%X      :SAISIR matrix (n x p) of predictive variables
%group  :SAISIR vector (n x 1) of integers indicating the group. Two observations 
%belonging to the same group have the same group number
%maxvar : integer indicating the maximum number of variables to be
%introduced.
%
%Output arguments:
%-----------------
%res with fields:
%ncorrect: vector of integers (1 x maxdim) indicating the number of
%correct classifications at each step. 
%classed: SAISIR vector of integer (n x 1) indicating the predicted group number
%for the model with maxvar variables introduced.
%confusion: SAISIR confusion matrix (row: actual group, column : predicted group). 
%varrank: vector of integer (1 x maxdim) indicating the index ("rank") of the
%introduced variables.
%
%The function computes a linear discriminant analysis introducing up to
%maxvar variables. At each step, the new variables giving the highest number
%of correctly classified samples is introduced.




[n,p]=size(saisir.d);
average=mean(saisir.d);
X=(saisir.d-ones(n,1)*average)/sqrt(n);% 
ngroup=max(group.d);
barycentre=zeros(ngroup,p);
model=zeros(n,p);
for g=1:ngroup
   barycentre(g,:)=mean(X(group.d==g,:));
   gn(g)=sum(group.d==1);
end
model=barycentre(group.d,:);
selected=zeros(1,maxvar);% index of the variables currently selected
sel=zeros(1,p);% boolean =1 variable already selected
warning off MATLAB:singularMatrix;
for var=1:maxvar;
   maxclassed=0;
   for scan=1:p;   
      %if(mod(scan,100)==0)
      %   disp([var scan]);
      %end
      if(sel(scan)==0);% variable not currenlty selected
         	selected(var)=scan;
   			x=X(:,selected(1:var));      
         	m=model(:,selected(1:var));
         	bary=barycentre(:,selected(1:var));
				M=inv(x'*x);
				for row=1:n
					delta=bary-ones(ngroup,1)*x(row,:);% delta from all the gavity center and current x g*p
				   dist=diag(delta*M*delta');   
					[aux1 predicted_group]=min(dist);
					predict(row)=predicted_group;   
            end;%for row
            nclassed=sum(predict'==group.d);
            if(nclassed>maxclassed) 
               disp(nclassed);
               maxclassed=nclassed;
               kept=scan;
            end%nclassed
         end;%sel(scan)         
	end %forscan   
   selected(var)=kept;     
	sel(kept)=1;
	disp(var);
    disp(['Introduced : ' saisir.v(selected(var),:)]);
 	ncorrect.d(var)=maxclassed;   
end%forvar
% reconstructing the final step
x=X(:,selected(1:var));
bary=barycentre(:,selected(1:var));
M=inv(x'*x);
for row=1:n
  	%size(m)
  	%size(x(row,:))
  	delta=bary-ones(ngroup,1)*x(row,:);% delta from all the gavity center and current x g*p
  	dist=diag(delta*M*delta');   
  	[aux1 predicted_group]=min(dist);
	predict(row)=predicted_group;   
end;
confusion=zeros(ngroup,ngroup);
for i=1:n
   confusion(group.d(i),predict(i))=confusion(group.d(i),predict(i))+1;
end
discrtype.ncorrect.d=ncorrect.d;
discrtype.ncorrect.v=saisir.v(selected(1:maxvar),:);
discrtype.ncorrect.i='Number of correct classifications';
discrtype.classed.d=predict';
discrtype.classed.i=saisir.i;
discrtype.classed.v='predicted group';
discrtype.confusion=confusion;
discrtype.varrank=selected(1:maxvar);