function [saisir] = moving_max(saisir1,window_size)
%moving_max         - replaces the central point of a moving window by the maximum value 
%function [X1] = moving_max(X,window_size)
%
%Input arguments
%===============
%X:SAISIR matrix of data (normally digitized signals such as spectra)
%window_size: integer giving the number of data points on which the max
%value is computed.
%
%Ouput arguments
%===============
%X1: matrix of local maxima
%
%The function replaces a given variable by the maximum value in the range defined
%by "window_size".
%(window_size-1)/2 variables are lost at the begining and the end of the signal. 
%
%For example with window_size = 5
%a given variable x(i) of index i is replaced by the local maximum of variables 
%x(i-2); x(i-1); x(i): x(i+1); x(i+2)


[nrow ncol]=size(saisir1.d);
    gap=floor(window_size/2);

for row= 1:nrow
    signal=saisir1.d(row,:);
    for col=1:ncol
        deb=col-gap; xend=col+gap;
        if(deb<1); deb=1;end
        if(xend>ncol); xend=ncol;end;
        saisir.d(row,col)=max(signal(deb:xend));
        
    end
end
saisir.i=saisir1.i;
saisir.v=saisir1.v;
