function res=pca_cano(col,ndim,graph);
%pca_cano         - generalized canonical analysis after PCAs on each table  
%function res=pca_cano(collection,ndim,graph);
%% ========================================================================
%input argument : 
%===============
%collection: array of SAISIR matrices with the same number of rows (see
%below)
%ndim  : dimension of each individual PCA (must be less than the smallest
%number of variables
%graph : if different from 0 : display examples of graph  
%
%let n be the number of observations in each table, k the number of tables
%%Output argument:
%===============
%res with fields
%compromise         : PCA giving the compromise 
%observation_score  : scores of each observation of each table (nxk rows)
%id_group           : groups identifying each observation in observation_score (for graph)
%projector          : struct array giving the vectors allowing the projection of each data set
%score_correlation: : correlations between compromise scores and table scores 
%table_average      : struct array giving the average of each original data table 
%Adapted from       : G. Saporta. Probabilits, analyse des donnes et statistiques.
%                   : Edition Technip, page 192 and followings. 
%% ========================================================================
%
%The function first computes PCA on each of the SAISIR matrices in
%"collection". Only the ndim PC scores are kept in each matrix.
%Canonical analysis is carried out on the series of scores.
%This procedure avoids to have inversion of the original matrices. The use
%of few scores guarantees that the computation is feasible, even if the
%original matrices have colinear variables. 
%
%
%Note : 
%the argument collection is obtained for example by
%collection(1)=data1;collection(2)=data2; ...;collection(k)=datak;
%In which data1, data2, ..., datak are SAISIR matrices with the same number
%of rows.
% 
if(nargin<3)
    graph=0;%% default : no representation
end
    
ntable=size(col,2);
for i=1:ntable
   chaine=['t' num2str(i) '             '];
   table_name(i,:)=chaine(1:10);
end

obs_name=col(1).i;% the identifiers of the first table taken as observation name
x=[];
previousn=1;
previousp=1;

for(i=1:ntable)
    disp(['Single PCA on table # ' num2str(i)]); 
    w=pca(col(i));
    p(i)=pca(col(i));   
    aux=p(i).score;
    xcode=num2str1(i,3);
    aux.v=addcode(aux.v,xcode);
    x=appendcol(x, selectcol(aux,1:ndim));
    ave(i)=p(i).average;
    aux=selectcol(p(i).eigenvec,1:ndim);
    [n1,p1]=size(aux.d);
    projector1(previousn:(n1+previousn-1),previousp:(p1+previousp-1))=aux.d;
    previousn=n1+previousn;
    previousp=p1+previousp;
end;
%res.concatened_pca=x;
std1=std(x.d,1);
x=norm_col(x);
res.compromise=pca(x);% 

%%Attempt to find the projection vector from the ORIGINAL data set
x1=[];
for(i=1:ntable)
    x1=appendcol(x1,col(i));
end
[n,p]=size(x1.d);
aux=diag(1./std1)*res.compromise.eigenvec.d;
projector.d=projector1*aux/n;%% final final projector 
clear projector1;

projector.i=x1.v;
%size(projector.d);
aux=num2str((1:size(projector.d,2))');

projector.v=addcode(aux,'A');
res.projector1=projector;
%% VERIFICATION HERE 
%test=center(x1);
%res.verif=saisir_mult(test,projector);
%%res.verif and res.compromise.score must be identical : it is the case
%return;
%Attempt to project each part and use a barycenter approach 

previousn=1;
[n1,p1]=size(col(1).d);
aux1=(1:n1)';
clear aux;
observation_score=[];%% as concatened rows
id_group.d=[];
x1=center(x1);
table_id=[];

for table=1:ntable
    %id_group.d=[id_group.d;aux1];
    this_table=col(table);
    this_table=center(this_table);
    [n1,p1]=size(this_table.d);
    id_group.d=[id_group.d;(1:n1)'];
    %disp([previousn ; (p1+previousn-1)]);
    aux1=selectrow(projector,previousn:(p1+previousn-1));
    aux=saisir_mult(this_table,aux1);
    observation_score=appendrow(observation_score,aux);
    cor=cormap(res.compromise.score,aux)';
    score_correlation.d(table,:)=diag(cor.d)';
    proj(table)=aux1;
    previousn=p1+previousn;
    table_id=[table_id; ones(n,1)*table];
end

observation_score.i=[num2str(table_id) observation_score.i];

res.observation_score=observation_score;
id_group.i=res.observation_score.i;
id_group.v='grouping according to observation';
res.id_group=id_group;
res.projector=proj;
score_correlation.i=num2str((1:ntable)');
score_correlation.v=res.compromise.score.v;
res.score_correlation=score_correlation;
res.table_average=ave;

disp('Maps of observation scores can be obtained using commands such as ''carte_barycentre(res.observation_score,col1,col2, res.id_group)''');
if(graph>0)
    carte(res.compromise.score,1,2);
    title('Compromise');
    carte_barycentre(res.observation_score,1,2,res.id_group);
    title('Barycentric presentation');
%     figure;
%     ellipse_map(res.observation_score,1,2,res.id_group,0.05);
%     title('Confidence ellipse representation');
end


