function w(xstruct,xcode);
%w          - w: (for "what") lists the fields which are present in a structure
%function res= w(xstruct);
%
%Input argument
%==============
%xstruct: any variable (supposed to be a structure with fields)
%
%Output argument
%==============
%none
%
%This function displays all the fields found in structures (given by a
%SAISIR function).
%"Matrix" or "Vector" means here "SAISIR matrix" or "SAISIR" vector" 
%
%Exemple of use
%...
%pls_res=crossvalpls1a(x,y,10,sel);%% modle de 1  10 dimensions 
%w(pls_res);%% gives the fields in "pls_res":
%"
%calibration
%        T        : matrix  94 X 10 
%        P        : matrix  10 X 1050 
%        beta     : vector  1050 X 1 
%        beta0    : =  12.7025 
%....
% validation 
%        PREDY : matrix  46 X 10 
%        RMSEV : vector  1 X 10 
%        r2    : vector  1 X 10 
%        T     : matrix  46 X 10 
%        OBSY  : vector  46 X 1 
%....
%"

if(nargin<2)
    xcode='';
end
[n,p]=size(xstruct);

if(issaisir(xstruct));
    [n,p]=size(xstruct.d);
    if(min(n,p)>1)
        xdisp(xcode,'Matrix dimensioned ',n,'X',p);
    else
        xdisp(xcode,'Vector dimensioned ',n,'X',p);
    end
    return;
end

if((max(n,p))>1);
    if(p<30)
        if(ischar(xstruct))
            if(n==1)
                xdisp(xcode,'"',xstruct,'"');
                return;
            end
        end
    end
    if(isnumeric(xstruct));
        nature='MATLAB matrix or vector';
    else
        nature='Complex structure';
    end
        xdisp(xcode,'Dimensions = ', n, 'X',p, ' . ', nature);
    return;
end
if(isnumeric(xstruct))
    xdisp(xcode,' = ', xstruct);
    return;
end
xfield=char(fieldnames(xstruct));
if(isempty(xfield))
    xdisp(xcode,'No fields in this object');
    return;
end

[n,p]=size(xfield);
for i=1:n
    aux=getfield(xstruct,xfield(i,:));
    if(issaisir(aux))
        [n,p]=size(aux.d);
        if(min(n,p)>1)
            xdisp(xcode,xfield(i,:),' : matrix ',n,'X',p);
        else
            if(max(n,p)>1)
                xdisp(xcode,xfield(i,:),' : vector ',n,'X',p);
            else
                xdisp(xcode,xfield(i,:),' : = ',aux.d);
            end
        end
    else
        %xdisp('fields ',xfield(i,:), ' with subfields : ');
        %xdisp('===============');
        xdisp(xcode,xfield(i,:));
        w(aux,[xcode '       ']);%% recursive command ???
        %xdisp('===============');
    end
end


function f = getfield(s,str)
f = s.(deblank(str));